from django.test import TransactionTestCase
from django.test.runner import DiscoverRunner
from mock import patch


class NoDbMixin(object):

    def build_suite(self, *args, **kwargs):
        suite = super(NoDbMixin, self).build_suite(*args, **kwargs)
        self._needs_db = any([isinstance(test, TransactionTestCase) for test in suite])
        return suite


    def setup_databases(self, **kwargs):
        if self._needs_db:
            return super(NoDbMixin, self).setup_databases(*args, **kwargs)
        if self.verbosity >= 1:
            print 'No DB tests detected. Skipping DB creation...'
        self._db_patch = patch('django.db.backends.util.CursorWrapper')
        self._db_mock.side_effect = RuntimeError('No testing the database!')
        return None


    def teardown_databases(self, old_config, **kwargs):
        if self._needs_db:
            return super(NoDbMixin, self).teardown_databases(*args, **kwargs)
        self._db_patch.stop()
        return None


class NoDbTestRunner(NoDbMixin, DiscoverRunner):

    def setup_databases(self, **kwargs):
        pass


    def teardown_databases(self, old_config, **kwargs):
        pass



# -*- coding: utf-8 -*-
"""
dj-nodb
=======

Custom django testrunner that eliminates test database creation when running tests.

Installation
------------

* pip install dj-nodb

This will place the custom testrunner (runner.py) at the root of your project. Alternatively you can move it to any part of your application you desire.

Usage (default)
---------------

Override django's default testrunner by adding the following to your settings

``TEST_RUNNER = 'djnodb.runner.NoDbTestRunner'``
"""

from setuptools import setup


setup(
    name='djnodb',
    packages=['djnodb'],
    version='0.0.4',
    description='custom django testrunner',
    url='https://github.com/weeksghost/dj-nodb',
    download_url='https://github.com/weeksghost/dj-nodb/tarball/0.0.4',
    author='Erik Marty',
    author_email='erikomarty@yahoo.com',
    license='Apache',
    classifiers=[
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Software Development :: Libraries :: Python Modules'
    ],
    install_requires=['mock']
)
